"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMessageForSlack = void 0;
/* eslint-disable @typescript-eslint/no-explicit-any */
const winston_slack_webhook_transport_1 = __importDefault(require("winston-slack-webhook-transport"));
const logger_types_1 = require("../../../logger/logger.types");
const getMessageForSlack = (info, nodeEnv) => {
    const errorObject = {
        context: info.context ?? info[Symbol.for('message')].context,
        message: info.message ?? undefined,
        level: info.level ?? info[Symbol.for('level')],
        splat: info[Symbol.for('splat')] ?? undefined,
        data: info.data ?? info[Symbol.for('message')].data,
        timestamp: info.timestamp ?? info[Symbol.for('message')].timestamp,
        symbolMessage: JSON.parse(info[Symbol.for('message')]) ?? undefined,
    };
    const isAxiosError = JSON.stringify(errorObject.symbolMessage.data).includes('AxiosError');
    const attachments = [];
    const fields = [];
    if (!isAxiosError) {
        for (const [key, value] of Object.entries(errorObject.symbolMessage.data)) {
            fields.push({
                title: `${key}:`,
                value: JSON.stringify(value, null, '\t'),
                short: false,
            });
        }
    }
    else {
        fields.push({
            title: `AxiosError:`,
            value: errorObject.symbolMessage.data.stack,
            short: false,
        });
    }
    attachments.push({
        // green
        color: '#36a64f',
        fields,
        footer: `*${errorObject.timestamp} - ${nodeEnv}*`.toUpperCase(),
    });
    const slackMessage = {
        attachments,
        blocks: [
            {
                type: 'header',
                text: {
                    type: 'plain_text',
                    text: ':x:The service got an error :x:',
                    emoji: true,
                },
            },
            {
                type: 'context',
                elements: [
                    {
                        type: 'mrkdwn',
                        text: `:exclamation:Error level: *${errorObject.level}*`.toUpperCase() + `:exclamation:`,
                    },
                ],
            },
            {
                type: 'divider',
            },
            {
                type: 'section',
                fields: [
                    {
                        type: 'mrkdwn',
                        text: '*Error Context:*',
                    },
                    {
                        type: 'mrkdwn',
                        text: errorObject.context,
                    },
                ],
            },
            {
                type: 'divider',
            },
            {
                type: 'section',
                fields: [
                    {
                        type: 'mrkdwn',
                        text: '*Error Response:*',
                    },
                    {
                        type: 'mrkdwn',
                        text: !isAxiosError ? JSON.stringify(errorObject.data, null, '\t') : JSON.stringify(errorObject.data.message, null, '\t'),
                    },
                ],
            },
            {
                type: 'divider',
            },
            {
                type: 'section',
                fields: [
                    {
                        type: 'mrkdwn',
                        text: '*Error Message:*',
                    },
                    {
                        type: 'mrkdwn',
                        text: errorObject.message,
                    },
                ],
            },
        ],
    };
    return slackMessage;
};
exports.getMessageForSlack = getMessageForSlack;
class SlackTransport {
    static create(nodeEnv, webhookUrl) {
        return new winston_slack_webhook_transport_1.default({
            level: logger_types_1.LOG_LEVEL.Error || logger_types_1.LOG_LEVEL.Fatal || logger_types_1.LOG_LEVEL.Emergency,
            webhookUrl,
            formatter: (info) => (0, exports.getMessageForSlack)(info, nodeEnv),
        });
    }
}
exports.default = SlackTransport;
